# -*- coding: utf-8 -*-

from django import forms
from django.contrib.auth.forms import UserCreationForm
from django.contrib.auth.models import User
from django.utils.translation import ugettext_lazy as _
from accounts.models import UserProfile


class UserRegistrationForm(UserCreationForm):
    email = forms.EmailField(label=_('E-mail'), max_length=75)

    def clean_email(self):
        email = self.cleaned_data['email']

        try:
            User.objects.get(email=email)
        except User.DoesNotExist:
            return email
        raise forms.ValidationError(_('A user with that e-mail already exists.'))


    def save(self, commit=True):
        user = super(UserRegistrationForm, self).save(commit=False)
        user.email = self.cleaned_data['email']

        if commit:
            user.save()

        return user


class UserEditForm(forms.ModelForm):

    new_password1   = forms.CharField(label=_('New password'),
                            widget=forms.PasswordInput, required=False)

    new_password2   = forms.CharField(label=_('New password confirmation'),
                            widget=forms.PasswordInput, required=False)

    email           = forms.EmailField(label=_('E-mail'), max_length=75)


    class Meta:
        model = UserProfile
        exclude = ('user', )


    def __init__(self, *args, **kwargs):
        super(UserEditForm, self).__init__(*args, **kwargs)

        if self.instance and self.instance.user:
            if 'email' not in self.initial:
                self.initial['email'] = self.instance.user.email


    def clean_new_password2(self):
        password1 = self.cleaned_data.get('new_password1')
        password2 = self.cleaned_data.get('new_password2')

        if password1 or password2:
            if password1 != password2:
                raise forms.ValidationError(_("The two password fields didn't match."))

        return password2


    def clean_email(self):
        email = self.cleaned_data['email']

        try:
            user = User.objects.get(email=email)
            if user == self.instance.user:
                return email
        except User.DoesNotExist:
            return email
        raise forms.ValidationError(_('A user with that e-mail already exists.'))


    def save(self, *args, **kwargs):
        super(UserEditForm, self).save(*args, **kwargs)

        if len(self.cleaned_data.get('new_password1', '')) > 0:
            self.instance.user.set_password(self.cleaned_data.get('new_password1'))

        self.instance.user.email = self.cleaned_data.get('email')
        self.instance.user.save()

